[Cbe-oss-dev] [PATCH 03/22]MARS/base: workload context increase reserved area

Yuji Mano yuji.mano at am.sony.com
Fri Mar 20 07:53:52 EST 2009


This patch increases the size of the reserved area within the workload context.
The workload context is 256 bytes, and the first 128 bytes is now reserved for
internal use and the remaining 128 bytes is available to the workload model.

Signed-off-by: Yuji Mano <yuji.mano at am.sony.com>
---
 base/include/common/mars/workload_types.h |   15 ++++++++-------
 base/src/common/workload_internal_types.h |    1 +
 2 files changed, 9 insertions(+), 7 deletions(-)

--- a/base/src/common/workload_internal_types.h
+++ b/base/src/common/workload_internal_types.h
@@ -139,6 +139,7 @@
 
 #define MARS_HOST_SIGNAL_EXIT			0x0	/* host exit flag */
 
+#define MARS_WORKLOAD_MODULE_SIZE		64
 #define MARS_WORKLOAD_MODULE_ALIGN		16
 
 /* 128 byte workload queue header structure */






More information about the cbe-oss-dev mailing list
--- a/base/include/common/mars/workload_types.h
+++ b/base/include/common/mars/workload_types.h
@@ -60,10 +60,10 @@
 #define MARS_WORKLOAD_MODULE_NAME_LEN_MAX	23
 
 /**
- * \ingroup group_mars_workload_module
+ * \ingroup group_mars_workload_queue
  * \brief Size of workload module structure
  */
-#define MARS_WORKLOAD_MODULE_SIZE		64
+#define MARS_WORKLOAD_RESERVED_SIZE		128
 
 /**
  * \ingroup group_mars_workload_queue
@@ -82,17 +82,18 @@
  * \brief MARS workload context structure
  *
  * This structure stores information about a specific workload.
  * The first \ref MARS_WORKLOAD_MODULE_SIZE bytes of the workload context
  * structure is reserved for the \ref mars_workload_module information.
  *
  * The remaining area of the structure can be used by the specific workload
  * model implementation as needed.
  */
 struct mars_workload_context {
-	/** workload module reserved area */
-	uint8_t workload_module[MARS_WORKLOAD_MODULE_SIZE];
+	/** workload reserved area */
+	uint8_t reserved[MARS_WORKLOAD_RESERVED_SIZE];
 	/** workload model specific data */
-	uint8_t context[MARS_WORKLOAD_CONTEXT_SIZE - MARS_WORKLOAD_MODULE_SIZE];
+	uint8_t data[MARS_WORKLOAD_CONTEXT_SIZE - MARS_WORKLOAD_RESERVED_SIZE];
 } __attribute__((aligned(MARS_WORKLOAD_CONTEXT_ALIGN)));
 
 /**
@@ -82,17 +82,18 @@
  *
  * This structure stores information about a specific workload.
- * The first \ref MARS_WORKLOAD_MODULE_SIZE bytes of the workload context
- * structure is reserved for the \ref mars_workload_module information.
+ *
+ * The first \ref MARS_WORKLOAD_RESERVED_SIZE bytes of the workload context
+ * structure is reserved and cannot be modified.
  *
  * The remaining area of the structure can be used by the specific workload